@@ -5,6 +5,9 @@ pub const START_NEGATION_CONDITIONAL_TAG: &str = "<!--[if !mso | IE]><!-->";
 pub const START_MSO_NEGATION_CONDITIONAL_TAG: &str = "<!--[if !mso]><!-->";
 pub const END_NEGATION_CONDITIONAL_TAG: &str = "<!--<![endif]-->";
 
+#[cfg(test)]
+pub const START_IE11_CONDITIONAL_TAG: &str = "<!--[if lte mso 11]>";
+
 pub fn conditional_tag<T: AsRef<str>>(input: T) -> String {
     START_CONDITIONAL_TAG.to_string() + input.as_ref() + END_CONDITIONAL_TAG
 }
