@@ -8,13 +8,13 @@ mod print;
 #[cfg(feature = "render")]
 mod render;
 
+use crate::prelude::hash::Map;
 pub use children::MJBodyChild;
-use std::collections::HashMap;
 
 pub const NAME: &str = "mj-body";
 
 #[derive(Debug, Default)]
 pub struct MJBody {
-    attributes: HashMap<String, String>,
+    attributes: Map<String, String>,
     children: Vec<MJBodyChild>,
 }
