@@ -1,11 +1,11 @@
 use super::MJBreakpoint;
+use crate::prelude::hash::Map;
 use crate::prelude::print::{self, Print};
 use crate::print_display;
-use std::collections::HashMap;
 
 impl Print for MJBreakpoint {
     fn print(&self, pretty: bool, level: usize, indent_size: usize) -> String {
-        let mut attrs = HashMap::<String, String>::new();
+        let mut attrs = Map::<String, String>::new();
         attrs.insert("width".to_string(), self.attributes.width.clone());
         print::open(super::NAME, Some(&attrs), true, pretty, level, indent_size)
     }
