@@ -1,14 +1,9 @@
-use super::{MJNavbarLink, MJNavbarLinkChild};
+use super::MJNavbarLink;
+use crate::mj_raw::MJRawChild;
 use crate::prelude::parse::{Error, Parsable, Parser};
 use crate::{parse_attribute, parse_child, parse_comment, parse_text};
 use xmlparser::{StrSpan, Tokenizer};
 
-impl Parsable for MJNavbarLinkChild {
-    fn parse<'a>(tag: StrSpan<'a>, _tokenizer: &mut Tokenizer<'a>) -> Result<Self, Error> {
-        Err(Error::UnexpectedElement(tag.start()))
-    }
-}
-
 #[derive(Debug, Default)]
 struct MJNavbarLinkParser(MJNavbarLink);
 
@@ -20,7 +15,7 @@ impl Parser for MJNavbarLinkParser {
     }
 
     parse_attribute!();
-    parse_child!(MJNavbarLinkChild);
+    parse_child!(MJRawChild);
     parse_comment!();
     parse_text!();
 }
