@@ -1,5 +1,6 @@
 use super::MJSocial;
 use super::MJSocialChild;
+use crate::mj_social_element::{MJSocialElement, NAME as MJ_SOCIAL_ELEMENT};
 use crate::prelude::parse::{Error, Parsable, Parser};
 use crate::{parse_attribute, parse_child, parse_comment};
 use xmlparser::{StrSpan, Tokenizer};
@@ -24,3 +25,12 @@ impl Parsable for MJSocial {
         MJSocialParser::default().parse(tokenizer)?.build()
     }
 }
+
+impl Parsable for MJSocialChild {
+    fn parse<'a>(tag: StrSpan<'a>, tokenizer: &mut Tokenizer<'a>) -> Result<Self, Error> {
+        match tag.as_str() {
+            MJ_SOCIAL_ELEMENT => Ok(MJSocialElement::parse(tag, tokenizer)?.into()),
+            _ => Err(Error::UnexpectedElement(tag.start())),
+        }
+    }
+}
