@@ -1,4 +1,3 @@
-mod children;
 #[cfg(feature = "json")]
 mod json;
 #[cfg(feature = "render")]
@@ -10,13 +9,13 @@ mod print;
 #[cfg(feature = "render")]
 mod render;
 
+use crate::mj_raw::MJRawChild;
 use crate::prelude::hash::Map;
-pub use children::MJSocialElementChild;
 
 pub const NAME: &str = "mj-social-element";
 
 #[derive(Debug, Default)]
 pub struct MJSocialElement {
     attributes: Map<String, String>,
-    children: Vec<MJSocialElementChild>,
+    children: Vec<MJRawChild>,
 }
